@@ -58,27 +58,6 @@
   (when (and value (stringp value))
     (substring-no-properties value)))
 
-(defun vulpea-db--extract-links-from-string (str)
-  "Extract org links from raw STR.
-
-Returns list of plists with :dest, :type, and :pos.
-This is used for extracting links from keyword values like
-#+TITLE where org-element does not parse links as elements."
-  (let ((result nil)
-        (pos 0))
-    (while (string-match org-link-bracket-re str pos)
-      (setq pos (match-end 0))
-      (let* ((raw-link (match-string 1 str))
-             (type-and-path (if (string-match "\\`\\([^:]+\\):\\(.*\\)" raw-link)
-                                (cons (match-string 1 raw-link)
-                                      (match-string 2 raw-link))
-                              (cons "fuzzy" raw-link))))
-        (push (list :dest (cdr type-and-path)
-                    :type (car type-and-path)
-                    :pos nil)
-              result)))
-    (nreverse result)))
-
 (defsubst vulpea-db--strings-no-properties (values)
   "Return VALUES list with text properties stripped from each element."
   (when values
@@ -366,8 +345,7 @@ Returns the #+TITLE keyword value if present, otherwise the filename base."
                              (org-element-property :key kw))
                             (vulpea-db--string-no-properties
                              (org-element-property :value kw)))))))
-    (or (when-let* ((title (cdr (assoc "TITLE" keywords))))
-          (org-link-display-format title))
+    (or (cdr (assoc "TITLE" keywords))
         (file-name-base path))))
 
 (defun vulpea-db--extract-file-node (ast path buffer file-title)
@@ -399,12 +377,8 @@ Returns nil if:
 
     ;; Only index if ID exists, not explicitly ignored, and not archived
     (when (and id (not ignored) (not archived))
-      (let* ((raw-title (cdr (assoc "TITLE" keywords)))
-             (title-links (when raw-title
-                            (vulpea-db--extract-links-from-string raw-title)))
-             (meta (vulpea-db--extract-meta ast))
-             (links (append title-links
-                            (vulpea-db--extract-links ast t)))  ; Don't recurse into headlines
+      (let* ((meta (vulpea-db--extract-meta ast))
+             (links (vulpea-db--extract-links ast t))  ; Don't recurse into headlines
              (aliases (vulpea-db--extract-aliases properties))
              (attach-dir (with-current-buffer buffer
                            (require 'org-attach)
@@ -458,9 +432,8 @@ Respects `vulpea-db-index-heading-level' setting."
                    (archived (vulpea-db--archived-p headline properties filetags)))
               ;; Only index if not explicitly ignored and not archived
               (unless (or ignored archived)
-                (let* ((title (org-link-display-format
-                              (vulpea-db--string-no-properties
-                               (org-element-property :raw-value headline))))
+                (let* ((title (vulpea-db--string-no-properties
+                               (org-element-property :raw-value headline)))
                        (tags (vulpea-db--strings-no-properties
                               (org-element-property :tags headline)))
                        (level (org-element-property :level headline))
@@ -471,26 +444,14 @@ Respects `vulpea-db-index-heading-level' setting."
                        (scheduled (org-element-property :scheduled headline))
                        (deadline (org-element-property :deadline headline))
                        (closed (org-element-property :closed headline))
-                       ;; Extract meta from the section element (first child of headline)
-                       ;; because org-element-map with NO-RECURSION 'headline won't
-                       ;; descend into a headline element itself
-                       (section (seq-find (lambda (el)
-                                            (eq (org-element-type el) 'section))
-                                          (org-element-contents headline)))
-                       (meta (when section
-                               (vulpea-db--extract-meta section)))
-                       (raw-title (vulpea-db--string-no-properties
-                                   (org-element-property :raw-value headline)))
-                       (title-links (vulpea-db--extract-links-from-string raw-title))
-                       (links (append title-links
-                                      (vulpea-db--extract-links headline t)))
+                       (meta (vulpea-db--extract-meta headline))
+                       (links (vulpea-db--extract-links headline t))
                        (outline-path (let (path
                                            (current headline))
                                        (while (setq current (org-element-property :parent current))
                                          (when (eq (org-element-type current) 'headline)
-                                           (push (org-link-display-format
-                                                  (vulpea-db--string-no-properties
-                                                   (org-element-property :raw-value current)))
+                                           (push (vulpea-db--string-no-properties
+                                                  (org-element-property :raw-value current))
                                                  path)))
                                        path))
                        (attach-dir (with-current-buffer buffer
@@ -583,8 +544,8 @@ Returns alist of (key . value) pairs."
       (lambda (drawer)
         (org-element-map drawer 'node-property
           (lambda (prop)
-            (cons (upcase (vulpea-db--string-no-properties
-                          (org-element-property :key prop)))
+            (cons (vulpea-db--string-no-properties
+                   (org-element-property :key prop))
                   (vulpea-db--string-no-properties
                    (org-element-property :value prop))))))
       nil t)))  ; First match only
@@ -596,54 +557,31 @@ Returns list of plists with :dest, :type, and :pos.
 Captures all link types: id:, roam:, file:, http:, https:,
 attachment:, elisp:, and any other `org-mode' link type.
 
-If NO-RECURSION is non-nil, stops recursion at note boundaries
-\(headlines with an ID property).  Links inside non-note subtrees
-are collected as part of the current node.  This prevents links
-from child notes leaking to the parent while still capturing
-links from plain (non-note) subtrees."
-  (if no-recursion
-      (vulpea-db--extract-links-stopping-at-notes ast-or-node)
-    ;; Normal case: search everything without restrictions
+If NO-RECURSION is non-nil, stops recursion at headline boundaries.
+This is useful for file-level extraction to avoid collecting links
+from child headlines.  For headline elements, this extracts links
+only from the section (direct content) without child headlines."
+  (if (and no-recursion (eq (org-element-type ast-or-node) 'headline))
+      ;; For headlines with no-recursion, only search the section
+      ;; (direct content before any child headlines)
+      (let ((section (org-element-map ast-or-node 'section #'identity nil t)))
+        (when section
+          (org-element-map section 'link
+            (lambda (link)
+              (let ((type (org-element-property :type link))
+                    (path (org-element-property :path link))
+                    (pos (org-element-property :begin link)))
+                (when (and type path)
+                  (list :dest path :type type :pos pos)))))))
+    ;; Normal case: search everything, optionally stopping at headlines
     (org-element-map ast-or-node 'link
       (lambda (link)
         (let ((type (org-element-property :type link))
               (path (org-element-property :path link))
               (pos (org-element-property :begin link)))
           (when (and type path)
-            (list :dest path :type type :pos pos)))))))
-
-(defun vulpea-db--extract-links-stopping-at-notes (node)
-  "Extract links from NODE, stopping at note boundaries.
-
-Collects links from NODE but does not descend into child
-headlines that have an ID property (note boundaries).  Links
-inside non-note child headlines are included."
-  (let ((result nil))
-    (vulpea-db--walk-links-skipping-notes node (lambda (link) (push link result)))
-    (nreverse result)))
-
-(defun vulpea-db--walk-links-skipping-notes (node callback)
-  "Walk NODE collecting links via CALLBACK, skipping note headlines.
-
-CALLBACK is called with a plist (:dest :type :pos) for each link.
-Descends into child headlines only if they lack an ID property."
-  (dolist (child (org-element-contents node))
-    (let ((child-type (org-element-type child)))
-      (cond
-       ;; Link element: collect it
-       ((eq child-type 'link)
-        (let ((type (org-element-property :type child))
-              (path (org-element-property :path child))
-              (pos (org-element-property :begin child)))
-          (when (and type path)
-            (funcall callback (list :dest path :type type :pos pos)))))
-       ;; Headline with ID: skip (note boundary)
-       ((and (eq child-type 'headline)
-             (org-element-property :ID child))
-        nil)
-       ;; Anything else (section, paragraph, headline without ID, etc.): recurse
-       ((org-element-contents child)
-        (vulpea-db--walk-links-skipping-notes child callback))))))
+            (list :dest path :type type :pos pos))))
+      nil nil (when no-recursion 'headline))))
 
 (defun vulpea-db--extract-meta (element)
   "Extract metadata from ELEMENT (AST or headline element).
